==> tabular-data-template-1.3.2-20140825.123856-2.jar: org/gcube/portlets/user/tdtemplate/client/rpc/TdTemplateService.java <==
package org.gcube.portlets.user.tdtemplate.client.rpc;

import java.util.List;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.tdtemplate.shared.ClientReportTemplateSaved;
import org.gcube.portlets.user.tdtemplate.shared.TdColumnDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateUpdater;
import org.gcube.portlets.user.tdtemplate.shared.validator.ViolationDescription;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;

/**
 * The client side stub for the RPC service.
 */
@RemoteServiceRelativePath("tdtemplate")
public interface TdTemplateService extends RemoteService {

	/**
	 * @return
	 */
	List<TdTTemplateType> getTemplateTypes();

	List<TdTColumnCategory> getColumnCategoryByTdTemplateDefinition(TdTemplateDefinition def) throws Exception;

	/**
	 * @param listColumns
	 * @return 
	 * @throws Exception
	 */
	ClientReportTemplateSaved submitTemplate(List<TdColumnDefinition> listColumns) throws Exception;

	/**
	 * @return
	 */
	List<String> getOnErrorValues();

	/**
	 * @param type
	 * @return
	 */
	String getConstraintForTemplateType(TdTTemplateType type);

	/**
	 * @param trId
	 * @return
	 * @throws Exception
	 */
	List<ColumnData> resolveColumnForDimension(TRId trId) throws Exception;

	/**
	 * @param templateId
	 * @return
	 * @throws Exception
	 */
	TdTemplateUpdater getTemplateUpdaterForTemplateId(long templateId)
			throws Exception;

	/**
	 * @param listColumns
	 * @return
	 * @throws Exception
	 */
	ClientReportTemplateSaved updateTemplate(List<TdColumnDefinition> listColumns)
			throws Exception;

	/**
	 * @return
	 */
	List<String> getAllowedLocales();

	/**
	 * @param columns
	 * @return
	 * @throws Exception
	 */
	boolean isValidTemplate(List<TdTColumnCategory> columns) throws Exception;

	/**
	 * @return
	 */
	List<ViolationDescription> getTemplateConstraintsViolations();

	/**
	 * @return
	 */
	String getTemplateHelper();

	/**
	 * @return
	 */
	List<String> getTimeDimensionPeriodTypes();

  
}

==> tabular-data-template-1.4.1-20150213.144624-2.jar: org/gcube/portlets/user/tdtemplate/client/rpc/TdTemplateService.java <==
package org.gcube.portlets.user.tdtemplate.client.rpc;

import java.util.List;

import org.gcube.portlets.user.td.gwtservice.shared.tr.ColumnData;
import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
import org.gcube.portlets.user.tdtemplate.shared.ClientReportTemplateSaved;
import org.gcube.portlets.user.tdtemplate.shared.TdBehaviourModel;
import org.gcube.portlets.user.tdtemplate.shared.TdColumnDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdFlowModel;
import org.gcube.portlets.user.tdtemplate.shared.TdLicenceModel;
import org.gcube.portlets.user.tdtemplate.shared.TdTColumnCategory;
import org.gcube.portlets.user.tdtemplate.shared.TdTTemplateType;
import org.gcube.portlets.user.tdtemplate.shared.TdTTimePeriod;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateDefinition;
import org.gcube.portlets.user.tdtemplate.shared.TdTemplateUpdater;
import org.gcube.portlets.user.tdtemplate.shared.validator.ViolationDescription;

import com.google.gwt.user.client.rpc.RemoteService;
import com.google.gwt.user.client.rpc.RemoteServiceRelativePath;

/**
 * The client side stub for the RPC service.
 */
@RemoteServiceRelativePath("tdtemplate")
public interface TdTemplateService extends RemoteService {

	/**
	 * @return
	 */
	List<TdTTemplateType> getTemplateTypes();

	List<TdTColumnCategory> getColumnCategoryByTdTemplateDefinition(TdTemplateDefinition def) throws Exception;

	/**
	 * @param listColumns
	 * @return 
	 * @throws Exception
	 */
	ClientReportTemplateSaved submitTemplate(List<TdColumnDefinition> listColumns, TdFlowModel flowAttached) throws Exception;

	/**
	 * @return
	 */
	List<String> getOnErrorValues();

	/**
	 * @param type
	 * @return
	 */
	String getConstraintForTemplateType(TdTTemplateType type);

	/**
	 * @param trId
	 * @return
	 * @throws Exception
	 */
	List<ColumnData> resolveColumnForDimension(TRId trId) throws Exception;

	/**
	 * @param templateId
	 * @return
	 * @throws Exception
	 */
	TdTemplateUpdater getTemplateUpdaterForTemplateId(long templateId)
			throws Exception;

	/**
	 * @param listColumns
	 * @return
	 * @throws Exception
	 */
	ClientReportTemplateSaved updateTemplate(List<TdColumnDefinition> listColumns)
			throws Exception;

	/**
	 * @return
	 */
	List<String> getAllowedLocales();

	/**
	 * @param columns
	 * @return
	 * @throws Exception
	 */
	boolean isValidTemplate(List<TdTColumnCategory> columns) throws Exception;

	/**
	 * @return
	 */
	List<ViolationDescription> getTemplateConstraintsViolations();

	/**
	 * @return
	 */
	String getTemplateHelper();

	/**
	 * @return
	 */
	List<TdTTimePeriod> getTimeDimensionPeriodTypes();

	/**
	 * @return
	 * @throws Exception
	 */
	List<TdLicenceModel> getLicences() throws Exception;

	/**
	 * @return
	 * @throws Exception
	 */
	List<TdBehaviourModel> getBehaviours() throws Exception;

	/**
	 * @param templateId
	 * @return
	 * @throws Exception
	 */
	TdFlowModel getFlowByTemplateId(long templateId) throws Exception;

  
}
